{"version":5,"vars":[{"line":7,"kind":12,"name":"with"},{"containerName":"main::","range":{"end":{"line":11,"character":9999},"start":{"character":0,"line":9}},"kind":12,"definition":"sub","name":"hello_world","line":9,"children":[]},{"line":13,"children":[],"kind":12,"range":{"end":{"line":15,"character":9999},"start":{"character":0,"line":13}},"containerName":"main::","definition":"sub","name":"foo"},{"line":17,"children":[],"definition":"sub","range":{"end":{"line":25,"character":9999},"start":{"character":0,"line":17}},"kind":12,"containerName":"main::","name":"routes"},{"name":"warnings","containerName":"","kind":2,"line":19},{"name":"set","kind":12,"line":32},{"kind":12,"line":32,"name":"port"},{"name":"Controllers","line":32,"kind":2,"containerName":"Dancer2::Dancer2"},{"line":34,"kind":12,"name":"controllers"},{"line":36,"kind":12,"name":"dance"}]}