{"vars":[{"name":"Carp","kind":2,"containerName":"","line":5},{"name":"routes","definition":"sub","range":{"start":{"line":7,"character":0},"end":{"line":11,"character":9999}},"containerName":"main::","kind":12,"children":[],"line":7},{"name":"croak","line":8,"kind":12}],"version":5}