{"vars":[{"containerName":"","kind":2,"name":"Carp","line":5},{"containerName":"","kind":2,"line":6,"name":"Exporter"},{"containerName":"main::","kind":13,"definition":"our","line":8,"name":"$VERSION"},{"line":9,"name":"@EXPORT","definition":"our","containerName":"main::","kind":13},{"containerName":null,"localvar":"my","name":"%dsl","line":11,"kind":13,"definition":"my"},{"kind":13,"containerName":null,"name":"@dsl","line":12},{"containerName":"main::","range":{"end":{"character":9999,"line":56},"start":{"character":0,"line":14}},"name":"controllers","line":14,"children":[{"kind":13,"definition":"my","containerName":"controllers","name":"$controllers","localvar":"my","line":15},{"containerName":"controllers","line":16,"name":"$package","localvar":"my","kind":13,"definition":"my"},{"kind":13,"containerName":"controllers","line":20,"name":"$controllers"},{"kind":13,"definition":"my","containerName":"controllers","localvar":"my","name":"$controller","line":22},{"containerName":"controllers","kind":13,"name":"$controller","line":24},{"line":24,"name":"can","kind":12,"containerName":"controllers"},{"name":"$controller","line":26,"kind":13,"containerName":"controllers"},{"name":"routes","line":26,"kind":12,"containerName":"controllers"},{"kind":13,"definition":"my","containerName":"controllers","name":"$action","localvar":"my","line":27},{"kind":13,"containerName":"controllers","line":27,"name":"$location"},{"name":"$func_name_or_sub","line":27,"kind":13,"containerName":"controllers"},{"containerName":"controllers","kind":13,"line":27,"name":"$_"},{"line":30,"name":"$croak","containerName":"controllers","kind":13},{"line":31,"name":"$dsl","kind":13,"containerName":"controllers"},{"kind":13,"containerName":"controllers","line":31,"name":"$action"},{"kind":13,"containerName":"controllers","line":34,"name":"$func_name_or_sub"},{"kind":13,"definition":"my","containerName":"controllers","localvar":"my","line":36,"name":"$f"},{"kind":13,"containerName":"controllers","line":37,"name":"$func_name_or_sub"},{"line":38,"name":"$f","kind":13,"containerName":"controllers"},{"kind":13,"containerName":"controllers","name":"$func_name_or_sub","line":38},{"containerName":"controllers","kind":13,"line":41,"name":"$f"},{"line":41,"name":"$controller","kind":13,"containerName":"controllers"},{"containerName":"controllers","kind":12,"name":"can","line":41},{"line":41,"name":"$func_name_or_sub","containerName":"controllers","kind":13},{"kind":13,"containerName":"controllers","line":45,"name":"$f"},{"name":"$cb","line":47,"localvar":"my","containerName":"controllers","definition":"my","kind":13},{"line":47,"name":"$package","kind":13,"containerName":"controllers"},{"kind":12,"containerName":"controllers","line":47,"name":"can"},{"name":"$action","line":47,"containerName":"controllers","kind":13},{"containerName":"controllers","kind":13,"line":51,"name":"$cb"},{"containerName":"controllers","kind":13,"name":"$cb","line":53},{"name":"$location","line":53,"containerName":"controllers","kind":13},{"name":"$f","line":53,"kind":13,"containerName":"controllers"}],"kind":12,"definition":"sub"},{"line":19,"name":"croak","kind":12},{"kind":12,"name":"croak","line":23},{"line":33,"name":"croak","kind":12},{"kind":12,"line":44,"name":"croak"},{"name":"croak","line":50,"kind":12}],"version":5}